==> haskell-hls-cabal-plugin-2.0.0.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-cabal-plugin-2.0.0.0-cnBODzDmRkLP7NJLfwbNy
key:                  hls-cabal-plugin-2.0.0.0-cnBODzDmRkLP7NJLfwbNy
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  11cf6c5902513b190f27484354d2a9a5
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Diagnostics
    Ide.Plugin.Cabal.LicenseSuggest Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-2.0.0.0-cnBODzDmRkLP7NJLfwbNy
depends:
    Cabal-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-9yFW5HMy3QJKMvZBMWGOPz
    ghcide-2.0.0.0-4aPLgQYWLRp5dlMy8HP7Nk
    hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    hls-graph-2.0.0.0-K5RL1HYdiga4ZnyILR6U72
    hls-plugin-api-2.0.0.0-81BySD4vqkK8F619Geablm
    lsp-1.6.0.0-JssQdMMkdnV6Y1aZJgkn3p
    lsp-types-1.6.0.1-7l6k7efB4A64H0TlEBBUmw
    regex-tdfa-1.3.2.2-LOCZw2rru5CARfqoQF4uzE stm-2.5.1.0 text-2.0.2
    unordered-containers-0.2.20-2oScjwZejU42oDENjBi2vG

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-cabal-plugin-2.0.0.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-cabal-plugin-2.0.0.0-FVFJDKPHsz22l12GgJQzCe
key:                  hls-cabal-plugin-2.0.0.0-FVFJDKPHsz22l12GgJQzCe
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  efc9ee515c5dbab7c86827a2af2faf36
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Diagnostics
    Ide.Plugin.Cabal.LicenseSuggest Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-cabal-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-2.0.0.0-FVFJDKPHsz22l12GgJQzCe
depends:
    Cabal-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-EuapY98rdrN25pzQYLq3T2
    ghcide-2.0.0.0-Ci6TVgvzKoWAIiVzj2Rzr7
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hls-graph-2.0.0.0-Gw9YhnDcvZxL5lCohGBSSg
    hls-plugin-api-2.0.0.0-JrJwLgvgULIKBoKUOgpowV
    lsp-1.6.0.0-2KeiYBxXLvVGpdNjURDfN5
    lsp-types-1.6.0.1-9PlWJ5C3jGZ30kxer1exM3
    regex-tdfa-1.3.2.2-I6io9mqXIhYC0c5uz00Sgn stm-2.5.1.0 text-2.0.2
    unordered-containers-0.2.20-FzN23deFW3GkzXU7VwkDd

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
